@@ -79,8 +79,10 @@ class Experiment:
         self.hub = pm.PMHub("tcp://localhost:5555")
         if device_serial == "auto":
             dev = self.hub.get_devices()[0]
-            self.dev = dev
-            return dev
+        else:
+            dev = [d for d in self.hub.get_devices() if d.device_serial == device_serial][0]
+        print("Connected to device with serial ", dev.device_serial)
+        return dev
 
     def test_device(self):
         print("Testing OD measurement...")
