@@ -152,9 +152,10 @@ def calculate_current(V, R, filter_errors=True):
             rsquared = 1 - resid / (n * np.var(V))
     if n < 5:
         print("fit with less than 5 points!")
+        print("R**2=%.6f, I=%.2fuA, V_bias=%.3f" % (rsquared, current, voltage_bias))
     current *= 1e6  # microAmps
 
-    #     print("R2=%.6f, I=%.2fuA, V_bias=%.3f"%(rsquared,current,voltage_bias))
+
     return current, voltage_bias, rsquared
 
 
