@@ -40,6 +40,12 @@ def shrink_time_window(timewindow, ODwindow):
             ODwindow = ODwindow[index + 1:]
     return timewindow, ODwindow
 
+def interpolate_nans(growth_rates):
+    nans = np.isnan(growth_rates)
+    x = lambda z: z.nonzero()[0]
+    growth_rates_2 = growth_rates.copy()
+    growth_rates_2[nans] = np.interp(x(nans), x(~nans), growth_rates[~nans])
+    return growth_rates_2
 
 def calculate_growth_rates(time, od, window_size=40):
     assert len(time) == len(od)
@@ -59,6 +65,8 @@ def calculate_growth_rates(time, od, window_size=40):
                 r = np.nan
             growth_rates[i] = r
             N0s[i] = N0
+    growth_rates = np.convolve(interpolate_nans(growth_rates), [1 / 120] * 120, mode='same')
+
     return growth_rates, N0s
 
 
